wrapplotly is a python wrapper for common plotly graph types.

- bar charts
- histograms
- scatterplots
- box plots
- line charts

wrapplotly allows creation of both single plots and subplot-type figures